.. automodule:: xclim.indices
   :members:
   :imported-members:
   :undoc-members:
   :show-inheritance:

Indices submodules
------------------

.. automodule:: xclim.indices.fwi
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: xclim.indices.generic
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: xclim.indices.run_length
   :members:
   :undoc-members:
   :show-inheritance:
